==> 5.8.0.tar.gz: ciphey/translations/ru/CODE_OF_CONDUCT.md <==
# Соглашение о кодексе поведения для вкладчиков

## Наше обязательство

В интересах создания открытой и доброжелательной атмосферы мы хотим взять на себя обязательство как участники и ответственные за наш проект сделать участие в проекте и наше сообщество свободным от притеснений - независимо от возраста, роста, инвалидности, этнической принадлежности, гендерной идентичности и самовыражения, уровня опыта, национальности, личной внешности, расы, вероисповедания или сексуальной идентичности или ориентации.

## Наши стандарты

включать примеры поведения, способствующего созданию позитивной среды:

* Использование привлекательных и увлекательных фраз
* Почитаются разные взгляды и опыт.
* Конструктивная критика вежливо принята.
* Сосредоточьтесь на том, что лучше для общества *
* Проявите понимание по отношению к другим членам общины *

включать примеры неприемлемого поведения:

* Использование сексуализированного языка, изображений или символики и нежелательные попытки сексуальной индукции.
* Оскорбительные / уничижительные комментарии, личные или политические атаки, использование Интернета для нечестного поведения.
* Общественное или частное домогательство
* Публикация частной информации других лиц, такой как физические или электронные адреса, без их прямого разрешения.
* Другое поведение, которое может быть сочтено неуместным в профессиональной среде. 

## Наши обязанности

Сотрудники по проектам несут ответственность за разъяснение стандартов приемлемого поведения и должны принимать надлежащие и справедливые меры по исправлению положения в ответ на любое неприемлемое поведение.

Менеджеры проектов имеют право и несут ответственность за удаление, редактирование или отклонение комментариев, коммитов, кода, вики-редакций, билетов в поддержку и других вкладов, которые не соответствуют этому Кодексу поведения, а также за временный или постоянный запрет этих вкладчиков на поведение, которое они считают неуместным, угрожающим, оскорбительным или причиняющим вред.

## Сфера действия

Настоящий Кодекс поведения применяется как на территории проекта, так и в общественных местах, где лицо представляет проект или его общину. Примеры представления проекта или сообщества включают использование официального адреса электронной почты проекта, отправку сообщений через общедоступные социальные сети или выступление в качестве представителя во время онлайн или оффлайн-мероприятия. Термин "представительство проекта" может быть доработан и уточнен руководителями проекта.

## Реализация

Случаи оскорблений, притеснений или иного неприемлемого поведения могут быть доведены до сведения проектной группы на brandon_skerrit. Все жалобы будут рассмотрены и расследованы, и по ним будут даны ответы, которые будут сочтены необходимыми и уместными в данных обстоятельствах. Команда проекта обязуется сохранять конфиденциальность в отношении тех, кто сообщал об инцидентах. Более подробная информация о конкретных принципах осуществления может быть представлена отдельно.

Руководители проектов, не соблюдающие Кодекс поведения или не обеспечивающие его соблюдение в меру своих знаний и убеждений, могут столкнуться с временными или постоянными последствиями, определяемыми другими членами руководства проекта.

## Ссылка

Настоящий Кодекс поведения основан на Пакте участника, версия 1.4, доступная по адресу: https://www.contributor-covenant.org/de/version/1/4/code-of-conduct.html.

==> 5.10.0.tar.gz: ciphey/translations/ru/CODE_OF_CONDUCT.md <==
# Соглашение о кодексе поведения для вкладчиков

## Наше обязательство

В интересах создания открытой и доброжелательной атмосферы мы хотим взять на себя обязательство как участники и ответственные за наш проект сделать участие в проекте и наше сообщество свободным от притеснений - независимо от возраста, роста, инвалидности, этнической принадлежности, гендерной идентичности и самовыражения, уровня опыта, национальности, личной внешности, расы, вероисповедания или сексуальной идентичности или ориентации.

## Наши стандарты

включать примеры поведения, способствующего созданию позитивной среды:

- Использование привлекательных и увлекательных фраз
- Почитаются разные взгляды и опыт.
- Конструктивная критика вежливо принята.
- Сосредоточьтесь на том, что лучше для общества \*
- Проявите понимание по отношению к другим членам общины \*

включать примеры неприемлемого поведения:

- Использование сексуализированного языка, изображений или символики и нежелательные попытки сексуальной индукции.
- Оскорбительные / уничижительные комментарии, личные или политические атаки, использование Интернета для нечестного поведения.
- Общественное или частное домогательство
- Публикация частной информации других лиц, такой как физические или электронные адреса, без их прямого разрешения.
- Другое поведение, которое может быть сочтено неуместным в профессиональной среде.

## Наши обязанности

Сотрудники по проектам несут ответственность за разъяснение стандартов приемлемого поведения и должны принимать надлежащие и справедливые меры по исправлению положения в ответ на любое неприемлемое поведение.

Менеджеры проектов имеют право и несут ответственность за удаление, редактирование или отклонение комментариев, коммитов, кода, вики-редакций, билетов в поддержку и других вкладов, которые не соответствуют этому Кодексу поведения, а также за временный или постоянный запрет этих вкладчиков на поведение, которое они считают неуместным, угрожающим, оскорбительным или причиняющим вред.

## Сфера действия

Настоящий Кодекс поведения применяется как на территории проекта, так и в общественных местах, где лицо представляет проект или его общину. Примеры представления проекта или сообщества включают использование официального адреса электронной почты проекта, отправку сообщений через общедоступные социальные сети или выступление в качестве представителя во время онлайн или оффлайн-мероприятия. Термин "представительство проекта" может быть доработан и уточнен руководителями проекта.

## Реализация

Случаи оскорблений, притеснений или иного неприемлемого поведения могут быть доведены до сведения проектной группы на brandon_skerrit. Все жалобы будут рассмотрены и расследованы, и по ним будут даны ответы, которые будут сочтены необходимыми и уместными в данных обстоятельствах. Команда проекта обязуется сохранять конфиденциальность в отношении тех, кто сообщал об инцидентах. Более подробная информация о конкретных принципах осуществления может быть представлена отдельно.

Руководители проектов, не соблюдающие Кодекс поведения или не обеспечивающие его соблюдение в меру своих знаний и убеждений, могут столкнуться с временными или постоянными последствиями, определяемыми другими членами руководства проекта.

## Ссылка

Настоящий Кодекс поведения основан на Пакте участника, версия 1.4, доступная по адресу: <https://www.contributor-covenant.org/de/version/1/4/code-of-conduct.html>.
